@@ -105,7 +105,7 @@ void KateViewManager::activateDocument(const QModelIndex &index)
 
 void KateViewManager::setupActions ()
 {
-  QAction *a;
+  KAction *a;
 
   /**
    * view splitting
@@ -134,15 +134,15 @@ void KateViewManager::setupActions ()
 
   m_closeView->setWhatsThis(i18n("Close the currently active splitted view"));
 
-  goNext = m_mainWindow->actionCollection()->addAction( "go_next" );
-  goNext->setText( i18n("Next View") );
+  goNext = m_mainWindow->actionCollection()->addAction( "go_next_split_view" );
+  goNext->setText( i18n("Next Split View") );
   goNext->setShortcut( Qt::Key_F8 );
   connect(goNext, SIGNAL(triggered()), this, SLOT(activateNextView()));
 
   goNext->setWhatsThis(i18n("Make the next split view the active one."));
 
-  goPrev = m_mainWindow->actionCollection()->addAction( "go_prev" );
-  goPrev->setText( i18n("Previous View") );
+  goPrev = m_mainWindow->actionCollection()->addAction( "go_prev_split_view" );
+  goPrev->setText( i18n("Previous Split View") );
   goPrev->setShortcut( Qt::SHIFT + Qt::Key_F8 );
   connect(goPrev, SIGNAL(triggered()), this, SLOT(activatePrevView()));
 
@@ -177,9 +177,12 @@ void KateViewManager::slotDocumentOpen ()
                                       cv->document()->url().url(),
                                       QString(), m_mainWindow, i18n("Open File"));
 
+    KateDocumentInfo docInfo;
+    docInfo.openedByUser = true;
+
     KTextEditor::Document *lastID = 0;
     for (KUrl::List::Iterator i = r.URLs.begin(); i != r.URLs.end(); ++i)
-      lastID = openUrl( *i, r.encoding, false );
+      lastID = openUrl( *i, r.encoding, false, false, docInfo);
 
     if (lastID)
       activateView (lastID);
@@ -213,9 +216,13 @@ void KateViewManager::slotDocumentClose ()
 
 }
 
-KTextEditor::Document *KateViewManager::openUrl (const KUrl &url, const QString& encoding, bool activate, bool isTempFile)
+KTextEditor::Document *KateViewManager::openUrl (const KUrl &url,
+                                                 const QString& encoding,
+                                                 bool activate,
+                                                 bool isTempFile,
+                                                 const KateDocumentInfo& docInfo)
 {
-  KTextEditor::Document *doc = KateDocManager::self()->openUrl (url, encoding, isTempFile);
+  KTextEditor::Document *doc = KateDocManager::self()->openUrl (url, encoding, isTempFile, docInfo);
 
   if (!doc->url().isEmpty())
     m_mainWindow->fileOpenRecent->addUrl( doc->url() );
@@ -289,15 +296,15 @@ bool KateViewManager::createView ( KTextEditor::Document *doc )
   delete view->actionCollection()->action( "set_confdlg" );
   delete view->actionCollection()->action( "editor_options" );
 
-  // popup menu
-  QMenu *menu = qobject_cast<QMenu*> (mainWindow()->factory()->container("ktexteditor_popup", mainWindow()));
-  if (menu)
-    view->setContextMenu (menu);
+  view->setContextMenu(view->defaultContextMenu());
 
   connect(view, SIGNAL(dropEventPass(QDropEvent *)), mainWindow(), SLOT(slotDropEvent(QDropEvent *)));
   connect(view, SIGNAL(focusIn(KTextEditor::View *)), this, SLOT(activateSpace(KTextEditor::View *)));
 
   activeViewSpace()->addView( view );
+
+  viewCreated(view);
+
   activateView( view );
 
   return true;
@@ -328,8 +335,8 @@ bool KateViewManager::deleteView (KTextEditor::View *view, bool delViewSpace)
 
 KateViewSpace* KateViewManager::activeViewSpace ()
 {
-  for ( QList<KateViewSpace*>::const_iterator it = m_viewSpaceList.begin();
-        it != m_viewSpaceList.end(); ++it )
+  for ( QList<KateViewSpace*>::const_iterator it = m_viewSpaceList.constBegin();
+        it != m_viewSpaceList.constEnd(); ++it )
   {
     if ( (*it)->isActiveSpace() )
       return *it;
@@ -352,8 +359,8 @@ KTextEditor::View* KateViewManager::activeView ()
 
   m_activeViewRunning = true;
 
-  for ( QList<KTextEditor::View*>::const_iterator it = m_viewList.begin();
-        it != m_viewList.end(); ++it )
+  for ( QList<KTextEditor::View*>::const_iterator it = m_viewList.constBegin();
+        it != m_viewList.constEnd(); ++it )
   {
     if ( m_activeStates[*it] )
     {
@@ -523,8 +530,8 @@ void KateViewManager::closeViews(KTextEditor::Document *doc)
 {
   QList<KTextEditor::View*> closeList;
 
-  for ( QList<KTextEditor::View*>::const_iterator it = m_viewList.begin();
-        it != m_viewList.end(); ++it)
+  for ( QList<KTextEditor::View*>::const_iterator it = m_viewList.constBegin();
+        it != m_viewList.constEnd(); ++it)
   {
     if ( (*it)->document() == doc )
       closeList.append( *it );
@@ -650,6 +657,8 @@ void KateViewManager::removeViewSpace (KateViewSpace *viewspace)
     // we are the root splitter and have only one child, which is also a splitter
     // -> eliminate the redundant splitter and move both children into the root splitter
     QList<int> sizes = splitter->sizes();
+    // adapt splitter orientation to the splitter we are about to delete
+    currentSplitter->setOrientation(splitter->orientation());
     currentSplitter->addWidget( splitter->widget(0) );
     currentSplitter->addWidget( splitter->widget(0) );
     delete splitter;
@@ -706,6 +715,7 @@ void KateViewManager::restoreViewConfiguration (const KConfigGroup& config)
   if( lastViewSpace >= 0 && lastViewSpace < m_viewSpaceList.size())
   {
     setActiveSpace( m_viewSpaceList.at( lastViewSpace ) );
+    setActiveView( m_viewSpaceList.at( lastViewSpace )->currentView() );
     m_viewSpaceList.at( lastViewSpace )->currentView()->setFocus();
   }
 
@@ -723,6 +733,8 @@ void KateViewManager::restoreViewConfiguration (const KConfigGroup& config)
   }
 
   updateViewSpaceActions();
+  // the view has (maybe) changed - promote it to the world
+  emit viewChanged();
 }
 
 void KateViewManager::saveSplitterConfig( QSplitter* s, KConfigBase* configBase, const QString& viewConfGrp )
@@ -788,8 +800,8 @@ void KateViewManager::restoreSplitter( const KConfigBase* configBase, const QStr
       // new view space as parent.
       setActiveSpace( vs );
 
-      vs->restoreConfig (this, configBase, *it);
       parent->addWidget( vs );
+      vs->restoreConfig (this, configBase, *it);
       vs->show();
     }
     else
