@@ -155,6 +155,7 @@ void CatalogItem::setComment(const QString& com)
 {
     d->_comment=com;
     d->_comment.squeeze();
+    d->_fuzzyCached=com.contains( QRegExp(fuzzyRegExpStr) );
 }
 
 void CatalogItem::setPlural(bool plural)
@@ -169,7 +170,7 @@ bool CatalogItem::isPlural() const
 
 bool CatalogItem::isFuzzy() const
 {
-    return d->_comment.contains( QRegExp(fuzzyRegExpStr) );
+    return d->_fuzzyCached;
 }
 
 bool CatalogItem::isUntranslated() const
@@ -295,6 +296,8 @@ QStringList CatalogItem::msgstrAsList() const
 
 void CatalogItem::setFuzzy()
 {
+    d->_fuzzyCached=true;
+
     QString& comment=d->_comment;
     if (comment.isEmpty())
     {
@@ -326,6 +329,8 @@ void CatalogItem::setFuzzy()
 
 void CatalogItem::unsetFuzzy()
 {
+    d->_fuzzyCached=false;
+
     QString& comment=d->_comment;
     //kDebug()<<comment;
 
@@ -343,6 +348,7 @@ void CatalogItem::unsetFuzzy()
 
 
 
+
 #if 0
 QString CatalogItem::nextError() const
 {
