@@ -24,6 +24,7 @@
 #include "catalogmodel.h"
 
 #include "catalog.h"
+#include "project.h"
 
 #include <kdebug.h>
 #include <klocale.h>
@@ -35,6 +36,7 @@
 CatalogTreeModel::CatalogTreeModel(QObject* parent, Catalog* catalog)
  : QAbstractItemModel(parent)
  , m_catalog(catalog)
+ , m_ignoreAccel(true)
 {
     connect(catalog,SIGNAL(signalEntryModified(DocPosition)),this,SLOT(reflectChanges(DocPosition)));
     connect(catalog,SIGNAL(signalFileLoaded()),this,SLOT(fileLoaded()));
@@ -62,6 +64,10 @@ void CatalogTreeModel::fileLoaded()
 
 void CatalogTreeModel::reflectChanges(DocPosition pos)
 {
+    emit dataChanged(index(pos.entry,0),index(pos.entry,DisplayedColumnCount-1));
+
+#if 0
+    I disabled dynamicSortFilter function
     //lazy sorting/filtering
     if (rowCount()<DYNAMICFILTER_LIMIT || m_prevChanged!=pos)
     {
@@ -74,6 +80,7 @@ void CatalogTreeModel::reflectChanges(DocPosition pos)
         }
     }
     m_prevChanged=pos;
+#endif
 }
 
 int CatalogTreeModel::rowCount(const QModelIndex& parent) const
@@ -94,17 +101,17 @@ QVariant CatalogTreeModel::headerData(int section, Qt::Orientation /*orientation
         case Source:    return i18nc("@title:column Original text","Source");
         case Target:    return i18nc("@title:column Text in target language","Target");
         case Notes:     return i18nc("@title:column","Notes");
-        case IsReady:  return i18nc("@title:column","Approved");
+        case TranslationStatus: return i18nc("@title:column","Translation Status");
     }
     return QVariant();
 }
 
-QVariant CatalogTreeModel::data(const QModelIndex& index,int role) const
+QVariant CatalogTreeModel::data(const QModelIndex& index, int role) const
 {
     if (m_catalog->numberOfEntries()<=index.row() )
         return QVariant();
 
-    if (role==Qt::FontRole && index.column()==Target)
+    if (role==Qt::FontRole/* && index.column()==Target*/)
     {
         bool fuzzy=!m_catalog->isApproved(index.row());
         bool modified=m_catalog->isModified(index.row());
@@ -120,13 +127,25 @@ QVariant CatalogTreeModel::data(const QModelIndex& index,int role) const
     {
         switch (index.column())
         {
-            case IsReady:   return m_catalog->isApproved(index.row());
+            case TranslationStatus:   return m_catalog->isApproved(index.row());
             case Empty:     return m_catalog->isEmpty(index.row());
             case State:     return int(m_catalog->state(index.row()));
             case Modified:  return m_catalog->isModified(index.row());
             default:        role=Qt::DisplayRole;
         }
     }
+    else if (role==StringFilterRole) //exclude UI strings
+    {
+        if (index.column()>Notes)
+            return QVariant();
+        else if (index.column()) //>Key
+        {
+            static const DocPosition::Part parts[]={DocPosition::Source, DocPosition::Target}; 
+            QString str=m_catalog->catalogString(DocPosition(index.row(),parts[index.column()==Target])).string;
+            return m_ignoreAccel?str.remove(Project::instance()->accel()):str;
+        }
+        role=Qt::DisplayRole;
+    }
     if (role!=Qt::DisplayRole)
         return QVariant();
 
@@ -144,9 +163,13 @@ QVariant CatalogTreeModel::data(const QModelIndex& index,int role) const
                 result+=note.content;
             return result;
         }
-        case IsReady:
-            static const char* noyes[]={I18N_NOOP("no"),I18N_NOOP("yes")};
-            return i18n(noyes[m_catalog->isApproved(index.row())]);
+        case TranslationStatus:
+            static QString statuses[]={i18nc("@info:status 'non-fuzzy' in gettext terminology","Ready"),
+                                    i18nc("@info:status 'fuzzy' in gettext terminology","Needs review"),
+                                    i18nc("@info:status","Untranslated")};
+            if (m_catalog->isEmpty(index.row()))
+                return statuses[2];
+            return statuses[!m_catalog->isApproved(index.row())];
     }
     return QVariant();
 }
@@ -158,7 +181,8 @@ CatalogTreeFilterModel::CatalogTreeFilterModel(QObject* parent)
 {
     setFilterKeyColumn(-1);
     setFilterCaseSensitivity(Qt::CaseInsensitive);
-    setDynamicSortFilter(true);
+    setFilterRole(CatalogTreeModel::StringFilterRole);
+    //setDynamicSortFilter(true);
 }
 
 void CatalogTreeFilterModel::setSourceModel(CatalogTreeModel* sourceModel)
@@ -187,7 +211,8 @@ void CatalogTreeFilterModel::setEntryFilteredOut(int entry, bool filteredOut)
 void CatalogTreeFilterModel::setFilerOptions(int o)
 {
     m_filerOptions=o;
-    setFilterCaseSensitivity(o&CaseSensitive?Qt::CaseInsensitive:Qt::CaseSensitive);
+    setFilterCaseSensitivity(o&CaseInsensitive?Qt::CaseInsensitive:Qt::CaseSensitive);
+    static_cast<CatalogTreeModel*>(sourceModel())->setIgnoreAccel(o&IgnoreAccel);
     invalidateFilter();
 }
 
@@ -197,7 +222,7 @@ bool CatalogTreeFilterModel::filterAcceptsRow(int source_row, const QModelIndex&
     bool accepts=true;
     if (bool(filerOptions&Ready)!=bool(filerOptions&NotReady))
     {
-        bool ready=sourceModel()->index(source_row,CatalogTreeModel::IsReady,source_parent).data(Qt::UserRole).toBool();
+        bool ready=sourceModel()->index(source_row,CatalogTreeModel::TranslationStatus,source_parent).data(Qt::UserRole).toBool();
         accepts=(ready==bool(filerOptions&Ready) || ready!=bool(filerOptions&NotReady));
     }
     if (accepts&&bool(filerOptions&NonEmpty)!=bool(filerOptions&Empty))
