@@ -1,11 +1,10 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2007                                               *
+ *   copyright (C) 2002-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -29,23 +28,41 @@
 #include "signalwidget.h"
 #include "forkjoinwidget.h"
 
-
 using namespace Uml;
 
-AssocRules::AssocRules() {}
-
-AssocRules::~AssocRules() {}
-
-bool allowAssociation( Association_Type/* assocType*/, const std::type_info/* &type*/ )
+/**
+ * Constructor.
+ */
+AssocRules::AssocRules()
 {
-    return false;
-
 }
 
-bool AssocRules::allowAssociation( Uml::Association_Type assocType, UMLWidget * widget ) {
-    Widget_Type widgetType = widget -> getBaseType();
+/**
+ * Destructor.
+ */
+AssocRules::~AssocRules()
+{
+}
+
+/**
+ * Returns whether an association is going to be allowed for the given
+ * values. This method is used to test if you can start an association.
+ */
+bool allowAssociation( Association_Type assocType, const std::type_info &type )
+{
+    Q_UNUSED(assocType); Q_UNUSED(type);
+    return false;
+}
+
+/**
+ * Returns whether an association is going to be allowed for the given
+ * values. This method is used to test if you can start an association.
+ */
+bool AssocRules::allowAssociation( Uml::Association_Type assocType, UMLWidget * widget )
+{
+    Widget_Type widgetType = widget->baseType();
     bool bValid = false;
-    for (int i = 0; i < m_nNumRules; i++) {
+    for (int i = 0; i < m_nNumRules; ++i) {
         if (assocType == m_AssocRules[i].assoc_type) {
             if (widgetType == m_AssocRules[i].widgetA_type
                     || widgetType == m_AssocRules[i].widgetB_type ) {
@@ -62,7 +79,7 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType, UMLWidget *
         else
             return false;
     }
-    AssociationWidgetList list = widget -> getAssocList();
+    AssociationWidgetList list = widget->associationWidgetList();
 
     switch( assocType ) {
     case at_Association:
@@ -83,7 +100,7 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType, UMLWidget *
 
     case at_Realization:  // one connected to widget only (a or b)
         foreach ( AssociationWidget* assoc, list ) {
-            if( assoc -> getAssocType() == at_Realization )
+            if( assoc->associationType() == at_Realization )
                 return false;
         }
         return true;
@@ -92,7 +109,7 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType, UMLWidget *
     case at_State:
         {
             StateWidget *pState = dynamic_cast<StateWidget*>(widget);
-            return (pState == NULL || pState->getStateType() != StateWidget::End);
+            return (pState == NULL || pState->stateType() != StateWidget::End);
         }
         break;
 
@@ -100,7 +117,7 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType, UMLWidget *
     case at_Exception:
         {
             ActivityWidget *pActivity = dynamic_cast<ActivityWidget*>(widget);
-            return (pActivity == NULL || pActivity->getActivityType() != ActivityWidget::End);
+            return (pActivity == NULL || pActivity->activityType() != ActivityWidget::End);
         }
         break;
 
@@ -125,20 +142,25 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType, UMLWidget *
     return false;
 }
 
-// when we know what we are going to connect both ends of the association to, we can
-// use this method.
+/**
+ * Returns whether an association is valid with the given variables.
+ * This method is used to finish an association.
+ * When we know what we are going to connect both ends of the association to, we can
+ * use this method.
+ */
 bool AssocRules::allowAssociation( Uml::Association_Type assocType,
                                    UMLWidget * widgetA, UMLWidget * widgetB,
-                                   bool extendedCheck ) {
-    Widget_Type widgetTypeA = widgetA->getBaseType();
-    Widget_Type widgetTypeB = widgetB->getBaseType();
+                                   bool extendedCheck )
+{
+    Widget_Type widgetTypeA = widgetA->baseType();
+    Widget_Type widgetTypeB = widgetB->baseType();
     bool bValid = false;
 
-    if ( widgetA->getUMLObject() == widgetB->getUMLObject() ) {
+    if ( widgetA->umlObject() == widgetB->umlObject() ) {
         return allowSelf( assocType, widgetTypeA );
     }
 
-    for (int i = 0; i < m_nNumRules; i++) {
+    for (int i = 0; i < m_nNumRules; ++i) {
         if (assocType == m_AssocRules[i].assoc_type) {
             if( (widgetTypeA == m_AssocRules[i].widgetA_type &&
                     widgetTypeB == m_AssocRules[i].widgetB_type) ||
@@ -157,11 +179,11 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType,
         return false;
     }
 
-    AssociationWidgetList list = widgetB -> getAssocList();
+    AssociationWidgetList list = widgetB->associationWidgetList();
 
     switch( assocType ) {
     case at_Association_Self:
-        if ( widgetA->getUMLObject() == widgetB->getUMLObject() )
+        if ( widgetA->umlObject() == widgetB->umlObject() )
             return true;
         break;
 
@@ -178,8 +200,8 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType,
     case at_Containment:   // can't have mutual containment
     case at_Generalization://can have many sub/super types but can't sup/sub each
         foreach ( AssociationWidget * assoc, list ) {
-            if( ( widgetA == assoc -> getWidget(A) || widgetA == assoc -> getWidget(B) )
-                    && assoc->getAssocType() == assocType )
+            if( ( widgetA == assoc->getWidget(A) || widgetA == assoc->getWidget(B) )
+                    && assoc->associationType() == assocType )
                 return false;
         }
         return true;
@@ -188,14 +210,14 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType,
     case at_Realization: // can only connect to abstract (interface) classes
         foreach( AssociationWidget * assoc, list ) {
             if( ( widgetA == assoc->getWidget(A) || widgetA == assoc->getWidget(B) )
-                    && assoc->getAssocType() == at_Realization ) {
+                    && assoc->associationType() == at_Realization ) {
                 return false;
             }
         }
-        if (widgetB->getBaseType() == wt_Class) {
-            return widgetB->getUMLObject()->getAbstract();
-        } else if (widgetB->getBaseType() == wt_Interface ||
-                   widgetB->getBaseType() == wt_Package) {
+        if (widgetB->baseType() == wt_Class) {
+            return widgetB->umlObject()->getAbstract();
+        } else if (widgetB->baseType() == wt_Interface ||
+                   widgetB->baseType() == wt_Package) {
             return true;
         }
         break;
@@ -205,10 +227,10 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType,
             StateWidget *stateA = dynamic_cast<StateWidget*>(widgetA);
             StateWidget *stateB = dynamic_cast<StateWidget*>(widgetB);
             if (stateA && stateB) {
-                if (stateB->getStateType() == StateWidget::Initial)
+                if (stateB->stateType() == StateWidget::Initial)
                     return false;
-                if (stateB->getStateType() == StateWidget::End &&
-                    stateA->getStateType() != StateWidget::Normal)
+                if (stateB->stateType() == StateWidget::End &&
+                    stateA->stateType() != StateWidget::Normal)
                     return false;
             }
         }
@@ -231,16 +253,16 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType,
                 isObjectNode = true;
 
             // no transitions to initial activity allowed
-            if (actB && actB->getActivityType() == ActivityWidget::Initial) {
+            if (actB && actB->activityType() == ActivityWidget::Initial) {
                 return false;
             }
             // actType -1 here means "not applicable".
             int actTypeA = -1;
             if (actA)
-                actTypeA = actA->getActivityType();
+                actTypeA = actA->activityType();
             int actTypeB = -1;
             if (actB)
-                actTypeB = actB->getActivityType();
+                actTypeB = actB->activityType();
             // only from a signalwidget a objectnode widget, a normal activity, branch or fork activity, to the end
             if ((actTypeB == ActivityWidget::End || actTypeB == ActivityWidget::Final) &&
                 actTypeA != ActivityWidget::Normal &&
@@ -250,7 +272,7 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType,
             }
             // only Forks and Branches can have more than one "outgoing" transition
             if (actA != NULL && actTypeA != ActivityWidget::Branch) {
-                AssociationWidgetList list = widgetA->getAssocList();
+                AssociationWidgetList list = widgetA->associationWidgetList();
                 foreach (AssociationWidget* assoc , list ) {
                     if (assoc->getWidget(A) == widgetA) {
                         return false;
@@ -284,23 +306,36 @@ bool AssocRules::allowAssociation( Uml::Association_Type assocType,
     return false;
 }
 
-bool AssocRules::allowRole( Uml::Association_Type assocType ) {
-    for( int i = 0; i < m_nNumRules; i++ )
+/**
+ * Returns whether to allow a role text for the given association type.
+ */
+bool AssocRules::allowRole( Uml::Association_Type assocType )
+{
+    for( int i = 0; i < m_nNumRules; ++i )
         if( assocType == m_AssocRules[ i ].assoc_type )
             return m_AssocRules[ i ].role;
     return false;
 }
 
-bool AssocRules::allowMultiplicity( Uml::Association_Type assocType, Uml::Widget_Type widgetType ) {
-    for( int i = 0; i < m_nNumRules; i++ )
+/**
+ * Returns whether to allow a multiplicity text for the given
+ * association and widget type.
+ */
+bool AssocRules::allowMultiplicity( Uml::Association_Type assocType, Uml::Widget_Type widgetType )
+{
+    for( int i = 0; i < m_nNumRules; ++i )
         if( assocType == m_AssocRules[ i ].assoc_type )
             if( widgetType == m_AssocRules[ i ].widgetA_type || widgetType == m_AssocRules[ i ].widgetB_type )
                 return m_AssocRules[ i ].multiplicity;
     return false;
 }
 
-bool AssocRules::allowSelf( Uml::Association_Type assocType, Uml::Widget_Type widgetType ) {
-    for( int i = 0; i < m_nNumRules; i++ )
+/**
+ * Returns whether to allow an association to self for given variables.
+ */
+bool AssocRules::allowSelf( Uml::Association_Type assocType, Uml::Widget_Type widgetType )
+{
+    for( int i = 0; i < m_nNumRules; ++i )
         if( assocType == m_AssocRules[ i ].assoc_type )
             if( widgetType == m_AssocRules[ i ].widgetA_type || widgetType == m_AssocRules[ i ].widgetB_type )
                 return m_AssocRules[ i ].self;
@@ -308,10 +343,16 @@ bool AssocRules::allowSelf( Uml::Association_Type assocType, Uml::Widget_Type wi
     return false;
 }
 
-Uml::Association_Type AssocRules::isGeneralisationOrRealisation(UMLWidget* widgetA, UMLWidget* widgetB) {
-    Widget_Type widgetTypeA = widgetA->getBaseType();
-    Widget_Type widgetTypeB = widgetB->getBaseType();
-    for (int i = 0; i < m_nNumRules; i++) {
+/**
+ * Returns whether an implements association should be a Realisation or
+ * a Generalisation.
+ * as defined in m_AssocRules.
+ */
+Uml::Association_Type AssocRules::isGeneralisationOrRealisation(UMLWidget* widgetA, UMLWidget* widgetB)
+{
+    Widget_Type widgetTypeA = widgetA->baseType();
+    Widget_Type widgetTypeB = widgetB->baseType();
+    for (int i = 0; i < m_nNumRules; ++i) {
         if (m_AssocRules[i].assoc_type == at_Realization &&
                 widgetTypeA == m_AssocRules[i].widgetA_type &&
                 widgetTypeB == m_AssocRules[i].widgetB_type) {
@@ -322,14 +363,14 @@ Uml::Association_Type AssocRules::isGeneralisationOrRealisation(UMLWidget* widge
 }
 
 AssocRules::Assoc_Rule AssocRules::m_AssocRules []= {
-    //  Association     widgetA         widgetB         role    multi   directional  self
+    //  Association     widgetA         widgetB         role    multi   direct. self
     //---------------+----------------+----------------+-------+-------+-------+---------
     { at_Association_Self,wt_Class,     wt_Class,       true,   true,   true,   true  },
     { at_Association_Self,wt_Object,    wt_Object,      true,   true,   true,   true  },
     { at_Association_Self,wt_Interface, wt_Interface,   true,   true,   true,   true  },
-    { at_Association,   wt_Class,       wt_Class,       true,   true,   true,   true },
-    { at_Association,   wt_Object,      wt_Object,      true,   true,   true,   true },
-    { at_Association,   wt_Interface,   wt_Interface,   true,   true,   true,   true },
+    { at_Association,   wt_Class,       wt_Class,       true,   true,   true,   true  },
+    { at_Association,   wt_Object,      wt_Object,      true,   true,   true,   true  },
+    { at_Association,   wt_Interface,   wt_Interface,   true,   true,   true,   true  },
     { at_Association,   wt_Interface,   wt_Class,       true,   true,   true,   false },
     { at_Association,   wt_Class,       wt_Interface,   true,   true,   true,   false },
     { at_Association,   wt_Datatype,    wt_Class,       true,   true,   true,   false },
@@ -363,7 +404,7 @@ AssocRules::Assoc_Rule AssocRules::m_AssocRules []= {
     { at_Aggregation,   wt_Class,       wt_Interface,   true,   true,   false,  false },
     { at_Aggregation,   wt_Class,       wt_Enum,        true,   true,   false,  false },
     { at_Aggregation,   wt_Class,       wt_Datatype,    true,   true,   false,  false },
-    { at_Dependency,    wt_Class,       wt_Class,       true,   false,  false,  true },
+    { at_Dependency,    wt_Class,       wt_Class,       true,   false,  false,  true  },
     { at_Dependency,    wt_UseCase,     wt_UseCase,     true,   false,  false,  false },
     { at_Dependency,    wt_Actor,       wt_Actor,       true,   false,  false,  false },
     { at_Dependency,    wt_Actor,       wt_UseCase,     true,   false,  false,  false },
@@ -423,7 +464,7 @@ AssocRules::Assoc_Rule AssocRules::m_AssocRules []= {
     { at_Activity,      wt_Pin,         wt_Pin,         true,   false,  true,   true  },
     { at_Activity,      wt_Activity,    wt_Pin,         true,   false,  true,   true  },
     { at_Activity,      wt_Pin,         wt_ForkJoin,    true,   false,  true,   true  },
-    { at_Activity,      wt_ForkJoin,    wt_Pin,    true,   false,  true,   true  },
+    { at_Activity,      wt_ForkJoin,    wt_Pin,         true,   false,  true,   true  },
     { at_Anchor,        wt_Class,       wt_Note,        false,  false,  false,  false },
     { at_Anchor,        wt_Package,     wt_Note,        false,  false,  false,  false },
     { at_Anchor,        wt_Interface,   wt_Note,        false,  false,  false,  false },
